### Name: var.def.ncv
### Title: Define a NetCDF Variable
### Aliases: var.def.ncv
### Keywords: file

### ** Examples

## define coordinate variables
rlon <- coord.def.ncv("rlon", seq(1,10), xtype="NC_FLOAT",
    att=list("axis", "X",
            "standard_name", "grid_longitude",
            "long_name", "longitude in rotated pole grid",
            "units", "degrees") )
rlat <- coord.def.ncv("rlat", 1.*seq(1,5),
    att=list("axis", "Y",
            "standard_name", "grid_latitude",
            "long_name", "latitude in rotated pole grid",
            "units", "degrees") )
hgt <- coord.def.ncv("hgt", 0.,
    att=list("axis", "Z", "long_name", "altitude", "units", "metre",
            "positive", "up") )
time <- coord.def.ncv("time", 0., 
    att=list("axis", "T", "calendar", "standard", "long_name", "time",
            "units", "days since 1979-01-01 00:00:00.0"), unlim=TRUE)

## define grid mapping variable
#gmap <- var.def.ncv("rotated_pole", 0.,
#    att=list("grid_mapping_name", "rotated_latitude_longitude",
#            "grid_north_pole_longitude", -170.,
#            "grid_north_pole_latitude", 32.5) )

## define data variable
pre <- var.def.ncv("precip", array(1., dim=c(10,5,1,1)), xtype="NC_FLOAT",
    dim=list(rlon, rlat, hgt, time),
    att=list("long_name", "precipitation", "units", "mm d-1",
            "_FillValue", -998.9, "grid_mapping", "rotated_pole"))

## write to file
var.put.ncv(paste(tempdir(),"/foo.nc",sep=""), pre)




